@@ -8,10 +8,12 @@ import socket
 import atexit
 import time
 import sys
+import os
 
 from django.core.management.base import NoArgsCommand as NoArgsCommandOrigin
 from django.core.management.base import BaseCommand as BaseCommandOrigin
 from django.utils.encoding import smart_str
+from django.db.utils import DatabaseError
 
 try:
     from django.utils.timezone import now
@@ -46,6 +48,9 @@ class BaseCommandMixin(object):
         self._mmc_script = self.__module__.split('.')[-1]
         self._mmc_lock = get_lock_instance(self._mmc_script)
         self._mmc_exc_info = None
+        self._mmc_hostname = socket.gethostname()
+        self._mmc_log_instance = None
+        self._mmc_resources = resource.getrusage(resource.RUSAGE_SELF)
 
     def __mmc_one_copy(self):
         try:
@@ -89,25 +94,54 @@ class BaseCommandMixin(object):
 
     def execute(self, *args, **options):
         self.__mmc_init(*args, **options)
+        self.__mmc_log_start()
         self.__mmc_execute(*args, **options)
         self.__mmc_done()
 
+    def __mmc_log_start(self):
+        try:
+            from mmc.models import MMCLog
+
+            self._mmc_log_instance = MMCLog.logging(
+                start=self._mmc_start_date,
+                hostname=self._mmc_hostname,
+                script=self._mmc_script,
+                elapsed=0.00,
+                success=None,
+                error_message="",
+                traceback="",
+                sys_argv=' '.join(map(unicode, sys.argv)),
+                memory=0.00,
+                cpu_time=0.00
+            )
+        except DatabaseError:
+            pass
+        except Exception, msg:
+            print '[MMC] Logging broken with message:', msg.__unicode__()
+
     def __mmc_store_log(self):
         try:
             from mmc.models import MMCLog
 
             memory = resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
+            resources = resource.getrusage(resource.RUSAGE_SELF)
+
+            utime = resources.ru_utime - self._mmc_resources.ru_utime
+            stime = resources.ru_stime - self._mmc_resources.ru_stime
+            div = 1024.0 if 'linux' in sys.platform else 1048576.0
 
             MMCLog.logging(
+                instance=self._mmc_log_instance,
                 start=self._mmc_start_date,
-                hostname=socket.gethostname(),
+                hostname=self._mmc_hostname,
                 script=self._mmc_script,
                 elapsed="%0.2f" % (time.time() - self._mmc_start_time),
                 success=self._mmc_success,
                 error_message=self._mmc_error_message,
                 traceback=self._mmc_traceback,
                 sys_argv=' '.join(map(unicode, sys.argv)),
-                memory="%0.2f" % (memory / 1048576.0),
+                memory="%0.2f" % (memory / div),
+                cpu_time="%0.2f" % (utime + stime),
             )
         except Exception, msg:
             print '[MMC] Logging broken with message:', msg.__unicode__()
@@ -116,15 +150,17 @@ class BaseCommandMixin(object):
         if not self._mmc_success and EMAIL_NOTIFICATION:
             from mmc.models import MMCEmail
 
-            MMCEmail.send(self._mmc_traceback)
+            MMCEmail.send(
+                self._mmc_hostname, self._mmc_script, self._mmc_traceback)
 
     def __mmc_send2sentry(self):
         if not self._mmc_success and SENTRY_NOTIFICATION:
             try:
                 from raven.contrib.django.raven_compat.models import client
 
-                client.captureException(exc_info=self._mmc_exc_info)
-            except ImportError:
+                client.captureException(
+                    exc_info=self._mmc_exc_info, extra=dict(os.environ))
+            except:
                 pass
 
     def __mmc_print_log(self):
@@ -139,9 +175,9 @@ class BaseCommandMixin(object):
 
     def _mmc_at_exit_callback(self, *args, **kwargs):
         self.__mmc_store_log()
+        self._mmc_lock.unlock()
         self.__mmc_send_mail()
         self.__mmc_send2sentry()
-        self._mmc_lock.unlock()
         self.__mmc_print_log()
 
 
