@@ -51,11 +51,12 @@ class MMCLog(models.Model):
     elapsed = models.FloatField()
     hostname = models.ForeignKey(MMCHost)
     script = models.ForeignKey(MMCScript)
-    success = models.BooleanField(default=False)
+    success = models.NullBooleanField(default=None)
     error_message = models.TextField(blank=True, null=True)
     traceback = models.TextField(blank=True, null=True)
     sys_argv = models.CharField(max_length=255, blank=True, null=True)
     memory = models.FloatField(default=0.00)
+    cpu_time = models.FloatField(default=0.00)
 
     def __unicode__(self):
         return self.script.name
@@ -70,11 +71,25 @@ class MMCLog(models.Model):
             name=kwargs['script'])[0]
         kwargs['hostname'] = MMCHost.objects.get_or_create(
             name=kwargs['hostname'])[0]
+        instance = kwargs.pop('instance', None)
+
+        def do_save():
+            if instance:
+                return cls.objects.filter(pk=instance.pk).update(**kwargs)
+            else:
+                return cls.objects.create(**kwargs)
 
         if not kwargs['script'].ignore and not kwargs['hostname'].ignore:
-            cls.objects.create(**kwargs)
-        elif not kwargs['success'] and kwargs['script'].save_on_error:
-            cls.objects.create(**kwargs)
+            return do_save()
+
+        if kwargs['success'] is False and kwargs['script'].save_on_error:
+            return do_save()
+
+    @classmethod
+    def get_lock_time(cls, script_name):
+        return round(int(cls.objects.values_list(
+            'elapsed', flat=True
+        ).filter(script__name=script_name).order_by('-elapsed')[:1][0]) + 1)
 
 
 class MMCEmail(models.Model):
@@ -93,12 +108,16 @@ class MMCEmail(models.Model):
         verbose_name_plural = 'Emails'
 
     @classmethod
-    def send(cls, message):
+    def send(cls, host_name, script_name, message):
         try:
             emails = list(cls.objects.values_list(
                 'email', flat=True).filter(is_active=True))
+            subject = SUBJECT % dict(script=script_name, host=host_name)
+
             if emails:
                 send_mail(
-                    SUBJECT, message, settings.DEFAULT_FROM_EMAIL, emails)
+                    subject, message, settings.DEFAULT_FROM_EMAIL, emails,
+                    fail_silently=True
+                )
         except Exception, msg:
             print '[MMC]', msg.__unicode__()
